@@ -1,9 +1,12 @@
+import os
+import sys
 import unittest
 
 from common import gobject, gtk, glade
 
 class APITest(unittest.TestCase):
     def testKeysyms(self):
+        self.failUnless('Escape' in dir(gtk.keysyms))
         self.failUnless(hasattr(gtk.keysyms, 'Escape'))
         self.assertEqual(gtk.keysyms.Escape, 0xFF1B)
 
@@ -25,3 +28,9 @@ class APITest(unittest.TestCase):
     def testGlade(self):
         self.failUnless(hasattr(glade, 'XML'))
         self.failUnless(issubclass(glade.XML, gobject.GObject))
+
+    def testReload(self):
+        # test for #349026
+        del sys.modules['gtk']
+        import gtk
+        reload(gtk)
